Struct WlCallback
pub struct WlCallback { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
callback object
Clients can handle the ‘done’ event to get notified when the related request is done.
Note, because wl_callback objects are created from multiple independent factory interfaces, the wl_callback interface is frozen at version 1.
See also the Event enum for this interface.